@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2015 Free Software Foundation, Inc.
+# Copyright (C) 2015, 2017 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@ srcdir=${srcdir:-.}
 # Follow a dir entry to a file in a subdirectory of infodir
 run_ginfo subdir
 printf 'Dq' >&7
-. $t/Timeout-test.inc
+timeout_test
 
 cat $GINFO_OUTPUT
 grep '^File: file-in-subdir.info' $GINFO_OUTPUT
